@@ -36,12 +36,16 @@ def clear_log(extract_path, max_files=MAX_EXTRACT_FILES):
 
 
 class VideoLog(object):
-    def __init__(self, dataset_id, vlog_size, max_output_size=(1920, 1080)):
+    def __init__(self, dataset_id, vlog_size, max_output_size=1920):
         self._vlog_size = vlog_size
         file_ac = FileAccess(storage="extract", resource_id=dataset_id)
         self._dest_path = file_ac.get_local_folder()
         self._dataset_id = dataset_id
-        self._max_output_size = max_output_size
+        if isinstance(max_output_size, list) or isinstance(max_output_size, tuple):
+            self._max_output_size = max(max_output_size)
+        elif isinstance(max_output_size, int):
+            self._max_output_size = max_output_size
+
         self._last_log = datetime.datetime(2000, 1, 1)
 
 
@@ -54,8 +58,8 @@ class VideoLog(object):
                 file_thumb = filename[:-4] + "_thumb.jpg"
                 img = image["input_image"]
                 scale = None
-                if max(img.shape) > max(self._max_output_size):
-                    img, scale = img_utils.resize_image_scale(img, max(self._max_output_size))
+                if max(img.shape) > self._max_output_size:
+                    img, scale = img_utils.resize_image_scale(img, self._max_output_size)
 
                 cv2.imwrite(os.path.join(self._dest_path, filename), img)
                 file_stat_img = os.stat(os.path.join(self._dest_path, filename))
